.. _sdv.constraints.base:

Constraints
===========

.. currentmodule:: sdv.constraints

Constraint
----------

.. autosummary::
   :toctree: api/

   Constraint
   Constraint.fit
   Constraint.transform
   Constraint.fit_transform
   Constraint.reverse_transform
   Constraint.is_valid
   Constraint.filter_valid
   Constraint.from_dict
   Constraint.to_dict
